#include <iostream>

#include <bobcat/ibase64stream>

using namespace std;
using namespace FBB;

int main()
{
    IBase64Stream<ENCRYPT> in(cin);
}
